Crate calisp
calisp
0.2.2
All Items
Crate Items
Structs
Crate
calisp
Structs

Calisp
Interpreter
Struct for handling the execution of Calisp code If you want to use this as an library, use [
new
] and [
run
] functions